#!/usr/bin/python

import logging
import tornado.web

from . import base

class IndexHandler(base.BaseHandler):
	def get(self):
		release = self.backend.releases.get_latest()
		if not release:
			raise tornado.web.HTTPError(404)

		# Cache this response for one minute
		self.set_expires(60)

		# Redirect to latest release page
		self.redirect("/download/%s" % release.slug)


class ReleaseHandler(base.BaseHandler):
	def get(self, slug):
		release = self.backend.releases.get_by_sname(slug)
		if not release:
			raise tornado.web.HTTPError(404)

		# Cache this response for ten minutes
		self.set_expires(600)

		self.render("download/release.html", release=release)


class ReleaseRedirectHandler(base.BaseHandler):
	def get(self, release):
		self.redirect("https://www.ipfire.org/download/%s" % release, permanent=True)


class FileHandler(base.BaseHandler):
	def prepare(self):
		self.set_header("Pragma", "no-cache")

	@base.ratelimit(minutes=5, requests=10)
	def get(self, filename):
		mirror = self.backend.mirrors.get_for_download(filename,
			country_code=self.current_country_code)

		# Send 404 if no mirror was found
		if not mirror:
			raise tornado.web.HTTPError(404, "Could not find a mirror for %s" % filename)

		# Construct the redirection URL
		url = mirror.build_url(filename)
		if not url:
			raise tornado.web.HTTPError(500, "Could not get download URL")

		# Log something
		logging.info("Sending client from %s to %s" % (self.current_country_code or "unknown", url))

		# Redirect the request
		self.redirect(url)

	# Allow HEAD
	head = get

	def write_error(self, status_code, **kwargs):
		"""
			Since we cannot deliver any CSS or similar here,
			we will have to redirect the user back to the main page
		"""
		self.redirect("https://www.ipfire.org/error/%s" % status_code)
